==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Effacer le journal</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Voulez-vous vraiment effacer le journal ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 jours</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semaine</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mois</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mois</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporter</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporter</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgence</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerte</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Débogage</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Démarrage</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critique</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (* .txt) ;; Doc (* .doc) ;; Xls (* .xls) ;; Html (* .html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportation...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportation réussie</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportation échouée</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporter un fichier</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Période :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Niveau :</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Liste des applications :</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Statut :</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Type d&apos;événement :</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID :</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Journaux de démarrage</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Journaux d&apos;extinction</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Journaux de connexion</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Débogage</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgence</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerte</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critique</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Le fichier journal est vide</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visionneuse de journaux</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer est un outil utile pour afficher les journaux système.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat de recherche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processus</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Type d&apos;événement</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Niveau :</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processus :</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Date et heure :</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID :</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Date et heure</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Journal système</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Journal du noyau</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Journal de démarrage</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Journal dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Journal Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Journal Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Journal d&apos;application</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Événement d&apos;arrêt du démarrage</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Journal dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Effacer le journal</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Voulez-vous vraiment effacer le journal ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 jours</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semaine</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mois</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mois</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporter</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgence</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerte</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Débogage</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Démarrage</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critique</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (* .txt) ;; Doc (* .doc) ;; Xls (* .xls) ;; Html (* .html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportation...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportation réussie</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportation échouée</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporter un fichier</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Période :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Niveau :</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Statut :</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Type d&apos;événement :</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID :</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Journaux de démarrage</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Journaux d&apos;extinction</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Journaux de connexion</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Débogage</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgence</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerte</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critique</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Le fichier journal est vide</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visionneuse de journaux</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer est un outil utile pour afficher les journaux système.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat de recherche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processus</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Type d&apos;événement</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Niveau :</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processus :</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Date et heure :</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID :</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Date de modification</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Date et heure</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Journal système</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Journal du noyau</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Journal de démarrage</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Journal dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Journal Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Journal Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Journal d&apos;application</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Événement d&apos;arrêt du démarrage</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Journal dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Autre journal</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Journal personnalisé</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Vous n&apos;avez pas la permission de le consulter</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Intervalle de rafraîchissement</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 s</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Pas de rafraîchissement</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Tout exporter</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Actualiser maintenant</translation>
    </message>
</context>
</TS>
